<?php
/**
 * Plugin Name: Dashboard News
 * Description: A simple plugin to display a news feed from multiple RSS feeds in the WordPress dashboard, with individual feed limits and a refresh button.
 * Version: 1.7
 * Author: SB
 */

// Add the dashboard widget
function dnfw_add_dashboard_widget() {
    wp_add_dashboard_widget(
        'dnfw_dashboard_widget',
        'Dashboard News',
        'dnfw_dashboard_widget_display'
    );
}
add_action('wp_dashboard_setup', 'dnfw_add_dashboard_widget');

// Display the widget content
function dnfw_dashboard_widget_display() {
    echo '<button id="dnfw-refresh" class="button button-primary">Refresh Feeds</button>';
    echo '<div id="dnfw-content">';
    dnfw_fetch_and_display_feeds();
    echo '</div>';
    dnfw_display_footer();
    ?>
    <script type="text/javascript">
        document.getElementById('dnfw-refresh').addEventListener('click', function() {
            var dnfwContent = document.getElementById('dnfw-content');
            dnfwContent.innerHTML = 'Refreshing...';
            fetch(ajaxurl + '?action=dnfw_refresh_feeds')
                .then(response => response.text())
                .then(data => dnfwContent.innerHTML = data);
        });
    </script>
    <?php
}

// Fetch and display feeds
function dnfw_fetch_and_display_feeds() {
    $rss_feeds = get_option('dnfw_rss_feeds', []);

    if (empty($rss_feeds)) {
        echo '<p>No RSS feeds provided.</p>';
        return;
    }

    foreach ($rss_feeds as $rss_feed) {
        $url = $rss_feed['url'];
        $limit = isset($rss_feed['limit']) ? intval($rss_feed['limit']) : 5;

        $rss = fetch_feed($url);
        if (is_wp_error($rss)) {
            echo '<p>Unable to fetch feed: ' . esc_html($url) . '</p>';
            continue;
        }

        $max_items = $rss->get_item_quantity($limit);
        $rss_items = $rss->get_items(0, $max_items);

        if ($max_items == 0) {
            echo '<p>No items in feed: ' . esc_html($url) . '</p>';
            continue;
        }

        echo '<h3 style="padding-top: 10px;">' . esc_html($rss->get_title()) . '</h3>';
        echo'<hr>';
        echo '<ul>';
        foreach ($rss_items as $item) {
            $title = esc_html($item->get_title());
            $link = esc_url($item->get_permalink());
            $date = esc_html($item->get_date('j F Y | g:i a'));
            echo "<li><a href='{$link}' target='_blank'>{$title}</a> <span style='font-size: 0.8em;'>{$date}</span></li>";
        }
        echo '</ul>';
    }
}

// Display footer
function dnfw_display_footer() {
    echo '<hr>';
    echo '<div style="margin-top: 10px; text-align: center;">';
    echo '<p style="text-decoration: none; display: flex; align-items: center; justify-content: center; margin: 0;">';
    echo ' Created by:';
    echo '<img src="https://wpscriptly.com/wp-content/uploads/2024/05/wpsc-logo-256.png" alt="Wp Scriptly" style="height: 20px; width: 20px; margin: 0 5px;">';
    echo '<a href="https://wpscriptly.com" target="_blank" style="text-decoration: none;">Wp Scriptly</a>';
    echo '</p>';
    echo '</div>';
}

// AJAX handler for refreshing feeds
function dnfw_refresh_feeds() {
    dnfw_fetch_and_display_feeds();
    wp_die();
}
add_action('wp_ajax_dnfw_refresh_feeds', 'dnfw_refresh_feeds');

// Add settings page
function dnfw_settings_page() {
    add_options_page(
        'Dashboard News Settings',
        'Dashboard News Settings',
        'manage_options',
        'dnfw-settings',
        'dnfw_settings_page_html'
    );
}
add_action('admin_menu', 'dnfw_settings_page');

// Settings page HTML
function dnfw_settings_page_html() {
    if (!current_user_can('manage_options')) {
        return;
    }

    if (isset($_POST['dnfw_rss_feeds'])) {
        $rss_feeds = [];
        $feed_lines = array_filter(array_map('trim', explode("\n", $_POST['dnfw_rss_feeds'])));
        
        foreach ($feed_lines as $line) {
            $parts = array_map('trim', explode('|', $line));
            if (count($parts) == 2) {
                $rss_feeds[] = [
                    'url' => esc_url_raw($parts[0]),
                    'limit' => intval($parts[1])
                ];
            }
        }

        update_option('dnfw_rss_feeds', $rss_feeds);
        echo '<div class="updated"><p>Settings saved.</p></div>';
    }

    $rss_feeds = get_option('dnfw_rss_feeds', []);
    $rss_lines = [];
    foreach ($rss_feeds as $feed) {
        $rss_lines[] = esc_url($feed['url']) . ' | ' . intval($feed['limit']);
    }
    $rss_textarea = implode("\n", $rss_lines);
    ?>
    <div class="wrap">
        <h1>Dashboard News Settings</h1>
        <form method="post">
            <label for="dnfw_rss_feeds">RSS Feed URLs and Limits (URL | Limit, one per line):</label>
            <p>
                <h3>Example:</h3>
                <code>https://example.com/feed | 5</code> <br>
                <code>https://anotherexample.com/feed | 10</code>
            </p>
            <textarea id="dnfw_rss_feeds" name="dnfw_rss_feeds" rows="10" cols="50"><?php echo esc_textarea($rss_textarea); ?></textarea>
            <br><br>
            <input type="submit" value="Save settings" class="button button-primary">
        </form>
        <?php dnfw_display_footer(); ?>
    </div>
    <?php
}
?>
